@@ -1,5 +1,5 @@
-from dataclasses import field, dataclass
-from typing import Optional
+from dataclasses import dataclass, field
+from typing import Any
 
 from hostingde.model import Model
 
@@ -13,8 +13,15 @@ class SoaValues(Model):
     ttl: int = field(default=172800)
     negative_ttl: int = field(default=3600)
 
-    def __init__(self, refresh: Optional[int] = 86400, retry: Optional[int] = 7200, expire: Optional[int] = 3600000,
-                 ttl: Optional[int] = 172800, negative_ttl: Optional[int] = 3600):
+    def __init__(
+        self,
+        refresh: int = 86400,
+        retry: int = 7200,
+        expire: int = 3600000,
+        ttl: int = 172800,
+        negative_ttl: int = 3600,
+        **kwargs: Any
+    ):
         """
         The SOA values object contains the time (seconds) used in a zone's SOA record. The maximum number of seconds is
         31556926 which equals one year. Exceeding the maximum and uncercutting the minimum values will cause the request
@@ -26,7 +33,7 @@ class SoaValues(Model):
         :param ttl: TTL for the SOA record. Default: 172800, minimum: 60.
         :param negative_ttl: Negative TTL for the SOA record. Default: 3600, minimum: 60.
         """
-        super().__init__()
+        super().__init__(**kwargs)
         self.refresh: int = refresh
         self.retry: int = retry
         self.expire: int = expire
